<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:output method="xml" indent="yes" doctype-system="DTD/callaway-trademark-application.dtd" encoding="UTF-8"/>
  <xsl:template match="/callaway-trademark-application">
    <callaway-trademark-application receive-num="" receive-date="" dtd-version="2.0.1" application-version="1.0.7" form-version="1.0.6" fee-version="1.0.2"  produced-by="applicant" recognizance2="y" recognizance3="y" form-type="n">
      <xsl:attribute name="case-code">
        <xsl:value-of select="case-code"/>
      </xsl:attribute>
	    <xsl:attribute name="registration-num">
       <xsl:value-of select="application-num"/>
     </xsl:attribute>
      <xsl:attribute name="application-num">
        <xsl:value-of select="application-num"/>
      </xsl:attribute>
      <xsl:attribute name="type-of-mark">
        <xsl:choose>
          <xsl:when test="type-of-mark='商標'">
            <xsl:text>trademark</xsl:text>
          </xsl:when>
          <xsl:when test="type-of-mark='商標(92年修正前服務標章)'">
            <xsl:text>trademark92</xsl:text>
          </xsl:when>
          <xsl:when test="type-of-mark='證明標章'">
            <xsl:text>certification-mark</xsl:text>
          </xsl:when>
          <xsl:when test="type-of-mark='團體標章'">
            <xsl:text>collective-membership-mark</xsl:text>
          </xsl:when>
          <xsl:when test="type-of-mark='團體商標'">
            <xsl:text>collective-trademark</xsl:text>
          </xsl:when>
        </xsl:choose>
      </xsl:attribute>
      <file-reference-id>
        <xsl:value-of select="file-reference-id"/>
      </file-reference-id>
      <mark-representation>
        <xsl:copy-of select="denomination"/>
      </mark-representation>
      <xsl:apply-templates select="parties"/>
      <callaway-reason>
        <xsl:value-of select="callaway-reason"/>
      </callaway-reason>
      <callaway-other-reason>
        <xsl:value-of select="callaway-other-reason"/>
      </callaway-other-reason>
      <signatories>
        <signatory>
          <name />
          <registered-number />
          <electronic-signature date="">
            <enhanced-signature>
              <pkcs7 />
            </enhanced-signature>
          </electronic-signature>
        </signatory>
      </signatories>
      <fee-sheet-trademark lang="" ro="">
        <xsl:attribute name="type-of-mark">
          <xsl:choose>
            <xsl:when test="type-of-mark='商標'">
              <xsl:text>trademark</xsl:text>
            </xsl:when>
            <xsl:when test="type-of-mark='商標(92年修正前服務標章)'">
              <xsl:text>trademark92</xsl:text>
            </xsl:when>
            <xsl:when test="type-of-mark='證明標章'">
              <xsl:text>certification-mark</xsl:text>
            </xsl:when>
            <xsl:when test="type-of-mark='團體標章'">
              <xsl:text>collective-membership-mark</xsl:text>
            </xsl:when>
            <xsl:when test="type-of-mark='團體商標'">
              <xsl:text>collective-trademark</xsl:text>
            </xsl:when>
          </xsl:choose>
        </xsl:attribute>
        <applicant-name>
          <name>
            <xsl:value-of select="fee-sheet/fee-name"/>
          </name>
          <iid>
            <xsl:value-of select="deposit-account/iid"/>
          </iid>
          <registered-number/>
        </applicant-name>
        <prescribed-fees currency=""/>
        <deposit-account>
          <authorization/>
          <ro>
            <country/>
          </ro>
          <account-no>
            <xsl:value-of select="deposit-account/account-no"/>
          </account-no>
          <receipt-type>
            <xsl:value-of select="deposit-account/receipt-type"/>
          </receipt-type>
          <date/>
          <name/>
          <registered-number/>
        </deposit-account>
        <dtext>
          <xsl:value-of select="fee-sheet/fee-dtext"/>
        </dtext>
      </fee-sheet-trademark>     
      <check-list>
        <xsl:apply-templates select="check-list"/>
      </check-list>
      <annotation>
        <dtext>
          <xsl:value-of select="dtext"/>
        </dtext>
        <registration-number>
          <xsl:value-of select="registration-number"/>
        </registration-number>
      </annotation>
    </callaway-trademark-application>
  </xsl:template>

  <xsl:template match="parties">
    <parties>
      <assignees>
        <xsl:apply-templates select="assignee"/>
      </assignees>
      <xsl:apply-templates select="correspondence-address"/>
      <agents>
        <xsl:apply-templates select="agent"/>
      </agents>
    </parties>
  </xsl:template>

  <xsl:template match="assignee">
    <assignee>
      <xsl:attribute name="sequence">
        <xsl:number value="position()" format="1"/>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="as-designated-representative='是'">
          <xsl:attribute name="designated-receiver">
            <xsl:value-of  select="translate(as-designated-representative,'是','y')"/>
          </xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="designated-receiver">
            <xsl:text>n</xsl:text>
          </xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <addressbook lang="tw">
        <xsl:choose>
          <xsl:when test="as-name-type='自然人'">
            <last-name>
              <xsl:value-of select="normalize-space(substring-before(as-tw-name,','))"/>
            </last-name>
            <first-name>
              <xsl:value-of select="normalize-space(substring-after(as-tw-name,','))"/>
            </first-name>
          </xsl:when>
          <xsl:otherwise>
            <orgname>
              <xsl:value-of select="normalize-space(as-tw-comname)"/>
            </orgname>
          </xsl:otherwise>
        </xsl:choose>
        <role>
          <xsl:value-of select="as-name-type"/>
        </role>
        <iid>
          <xsl:value-of select="as-tw-iid"/>
        </iid>
        <registered-number/>
        <representative>
          <xsl:value-of select="as-tw-representative"/>
        </representative>
        <address lang="tw">
          <zip-code>
            <xsl:value-of select="as-zip-code"/>
          </zip-code>
          <dtext>
            <xsl:value-of select="as-tw-address"/>
          </dtext>
        </address>
        <phones>
          <phone-region/>
          <phone>
            <xsl:value-of select="as-tw-phone"/>
          </phone>
        </phones>
        <fax>
          <xsl:value-of select="as-tw-fax"/>
        </fax>
        <cell-phone>
          <xsl:value-of select="as-tw-cell-phone"/>
        </cell-phone>
        <email>
          <xsl:value-of select="as-tw-email"/>
        </email>
      </addressbook>
      <addressbook lang="en">
        <xsl:choose>
          <xsl:when test="as-name-type='自然人'">
            <last-name>
              <xsl:value-of select="normalize-space(substring-before(as-en-name,','))"/>
            </last-name>
            <first-name>
              <xsl:value-of select="normalize-space(substring-after(as-en-name,','))"/>
            </first-name>
          </xsl:when>
          <xsl:otherwise>
            <orgname>
              <xsl:value-of select="normalize-space(as-en-comname)"/>
            </orgname>
          </xsl:otherwise>
        </xsl:choose>
        <iid>
          <xsl:value-of select="as-tw-iid"/>
        </iid>
        <registered-number/>
        <representative>
          <xsl:value-of select="as-en-representative"/>
        </representative>
        <address lang="en">
          <dtext>
            <xsl:value-of select="as-en-address"/>
          </dtext>
        </address>
        <email/>
      </addressbook>
      <nationality>
        <country>
          <xsl:value-of select="substring(as-country,'3')"/>
        </country>
        <country-code>
          <xsl:value-of select="substring(as-country,'1','2')"/>
        </country-code>
      </nationality>
      <residence>
        <country>
          <xsl:value-of select="as-living-country"/>
        </country>
      </residence>
      <legal-representative lang="tw">
        <addressbook lang="tw">
          <last-name>
            <xsl:value-of select="normalize-space(substring-before(as-tw-legal-name,','))"/>
          </last-name>
          <first-name>
            <xsl:value-of select="normalize-space(substring-after(as-tw-legal-name,','))"/>
          </first-name>
          <iid>
            <xsl:value-of select="as-tw-legal-iid"/>
          </iid>
          <registered-number />
          <address lang="tw">
            <dtext />
          </address>
          <email />
        </addressbook>
      </legal-representative>
    </assignee>
  </xsl:template>

  <xsl:template match="correspondence-address">
    <correspondence-address>
      <addressbook lang="tw">
        <last-name>
          <xsl:value-of select="normalize-space(substring-before(co-tw-name,','))"/>
        </last-name>
        <first-name>
          <xsl:value-of select="normalize-space(substring-after(co-tw-name,','))"/>
        </first-name>
        <iid>
          <xsl:value-of select="co-tw-iid"/>
        </iid>
        <registered-number/>
        <address lang="tw">
          <zip-code>
            <xsl:value-of select="co-zip-code"/>
          </zip-code>
          <dtext>
            <xsl:value-of select="co-tw-address"/>
          </dtext>
        </address>
        <phones>
          <phone-region/>
          <phone>
            <xsl:value-of select="co-tw-phone"/>
          </phone>
        </phones>
        <email/>
      </addressbook>
    </correspondence-address>
  </xsl:template>

  <xsl:template match="agent">
    <agent agent-type="agent" rep-type="agent">
      <xsl:attribute name="sequence">
        <xsl:number value="position()" format="1"/>
      </xsl:attribute>
      <addressbook lang="tw">
        <last-name>
          <xsl:value-of select="normalize-space(substring-before(ag-tw-name,','))"/>
        </last-name>
        <first-name>
          <xsl:value-of select="normalize-space(substring-after(ag-tw-name,','))"/>
        </first-name>
        <iid>
          <xsl:value-of select="ag-tw-iid"/>
        </iid>
        <registered-number/>
        <address lang="tw">
          <zip-code>
            <xsl:value-of select="ag-zip-code"/>
          </zip-code>
          <dtext>
            <xsl:value-of select="ag-tw-address"/>
          </dtext>
        </address>
        <phones>
          <phone-region/>
          <phone>
            <xsl:value-of select="ag-tw-phone"/>
          </phone>
        </phones>
        <fax>
          <xsl:value-of select="ag-tw-fax"/>
        </fax>
        <cell-phone>
          <xsl:value-of select="ag-tw-cell-phone"/>
        </cell-phone>
        <email>
          <xsl:value-of select="ag-tw-email"/>
        </email>
      </addressbook>
      <customer-number>
        <xsl:value-of select="ag-customer-number"/>
      </customer-number>
    </agent>
  </xsl:template>

  <xsl:template match="check-list">
    <xsl:apply-templates select="power-of-attorney"/>
    <xsl:apply-templates select="power-of-attorney-translation"/>
    <xsl:apply-templates select="contact"/>
    <xsl:apply-templates select="metastasis-contracts"/>
    <xsl:apply-templates select="metastasis-contracts-translation"/>
    <xsl:apply-templates select="gift-contracts-translation"/>
    <xsl:apply-templates select="gift-contracts-translation-translation"/>
    <xsl:apply-templates select="certificate-inherit"/>
    <xsl:apply-templates select="original-owner-death-doc"/>
    <xsl:apply-templates select="original-owner-death-doc-translation"/>
    <xsl:apply-templates select="original-owner-allacount-book"/>
    <xsl:apply-templates select="original-owner-allacount-book-translation"/>
    <xsl:apply-templates select="exclusive-right-to-proof"/>
    <xsl:apply-templates select="certificate-taxes"/>
    <xsl:apply-templates select="certificate-taxes-paid"/>
    <xsl:apply-templates select="certificate-taxes-unpaid"/>
    <xsl:apply-templates select="taxable-amount-doc"/>
    <xsl:apply-templates select="agree-trans-doc"/>
    <xsl:apply-templates select="gifts-amount-doc"/>
    <xsl:apply-templates select="court-shot-given-proof"/>
    <xsl:apply-templates select="company-combined-documents"/>
    <xsl:apply-templates select="company-combined-documents-translation"/>
    <xsl:apply-templates select="cl-articles-trademark"/>
    <xsl:apply-templates select="cl-articles-trademark-translation"/>
    <xsl:apply-templates select="cl-articles-collective-trademark"/>
    <xsl:apply-templates select="cl-articles-collective-trademark-translation"/>
    <xsl:apply-templates select="cl-articles-membership"/>
    <xsl:apply-templates select="cl-articles-membership-translation"/>
    <xsl:apply-templates select="cl-articles-certification"/>
    <xsl:apply-templates select="cl-articles-certification-translation"/>
    <xsl:apply-templates select="assignment-certificate"/>
    <xsl:apply-templates select="allother-consent"/>
    <xsl:apply-templates select="cl-other-document"/>
  </xsl:template>

  <xsl:template match="cl-mark-representation">
    <cl-mark-representation add="y" img-format="jpg" >
      <xsl:attribute name="sequence">
        <xsl:number value="position()" format="1"/>
      </xsl:attribute>
      <xsl:attribute name="he">
        <xsl:value-of select="img/@he"/>
      </xsl:attribute>
      <xsl:attribute name="wi">
        <xsl:value-of select="img/@wi"/>
      </xsl:attribute>
      <xsl:attribute name="file">
        <xsl:value-of select="img/@file"/>
      </xsl:attribute>
    </cl-mark-representation>
  </xsl:template>

  <xsl:attribute-set name="Add">
    <xsl:attribute name="add">y</xsl:attribute>
  </xsl:attribute-set>

  <xsl:template match="power-of-attorney | power-of-attorney-translation | contact | metastasis-contracts | metastasis-contracts-translation | gift-contracts-translation | gift-contracts-translation-translation | certificate-inherit | original-owner-death-doc | original-owner-death-doc-translation | original-owner-allacount-book | original-owner-allacount-book-translation | exclusive-right-to-proof | certificate-taxes | certificate-taxes-paid | certificate-taxes-unpaid | taxable-amount-doc | agree-trans-doc | gifts-amount-doc | court-shot-given-proof | company-combined-documents | company-combined-documents-translation | cl-articles-trademark | cl-articles-trademark-translation | cl-articles-collective-trademark | cl-articles-collective-trademark-translation | cl-articles-membership | cl-articles-membership-translation | cl-articles-certification | cl-articles-certification-translation | assignment-certificate | allother-consent">
    <xsl:copy use-attribute-sets="Add">
      <xsl:attribute name="list-seq">
        <xsl:value-of select="@list-seq"/>
      </xsl:attribute>
      <xsl:apply-templates select="*|node()"/>
    </xsl:copy>
  </xsl:template>

  <xsl:template match="cl-other-document">
    <cl-other-document>
      <xsl:attribute name="list-seq">
        <xsl:value-of select="@list-seq"/>
      </xsl:attribute>
      <doc-description>
        <xsl:value-of select="doc-description"/>
      </doc-description>
      <doc-filename>
        <xsl:value-of select="doc-filename"/>
      </doc-filename>
    </cl-other-document>
  </xsl:template>

  <!--<xsl:template match="annotation">
    <dtext>
      <xsl:value-of select="dtext"/>
    </dtext>
    <registration-number>
      <xsl:value-of select="registration-number"/>
    </registration-number>
  </xsl:template> -->
  
</xsl:stylesheet>
